from django import forms
from django.forms.widgets import TextInput
from django.utils.translation import gettext_lazy as _

from wagtail.utils.widgets import WidgetWithScript

class ShowSimilarWidget(WidgetWithScript, TextInput):
    template_name = "wagtailshowsimilar/showsimilar.html"

    def __init__(self, instance, threshold, max_items):
        self.instance = instance
        self.threshold = threshold 
        self.max_items = max_items

        super().__init__()

    def get_context(self, name, value, attrs):
        context = super().get_context(name, value, attrs)

        if context["widget"]["value"] is None:
           context["widget"]["value"] = "" 

        meta = self.instance._meta
        context["label"] = _("Similar items:")
        context["target_model"] = f"{meta.app_label}.{meta.model_name}"
        context["instance_id"] = self.instance.id
        context["threshold"] = self.threshold
        context["max_items"] = self.max_items

        return context

    @property
    def media(self):
        return forms.Media(
            js=["wagtailshowsimilar/showsimilar.js"],
        )



from wagtail.admin.edit_handlers import FieldPanel

from .widgets import ShowSimilarWidget

class ShowSimilarPanel(FieldPanel):
    def __init__(self, *args, **kwargs):
        self.threshold = kwargs.pop("score_threshold", 20)
        self.max_items = kwargs.pop("max_items", 10)

        super().__init__(*args, **kwargs)

        self.widget = ShowSimilarWidget(
            instance=None,
            threshold=self.threshold,
            max_items=self.max_items
        )

    def on_instance_bound(self):
        self.widget.instance = self.instance

    def clone(self):
        return self.__class__(
            field_name=self.field_name,
            classname=self.classname,
            score_threshold=self.threshold,
            max_items=self.max_items
        )



from setuptools import setup, find_packages

from wagtailshowsimilar import __version__

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="wagtail-showsimilar",
    version=__version__,
    author="ongchi",
    author_email="ongchi@users.noreply.github.com",
    description="wagtail input panel",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ongchi/wagtail-showsimilar",
    project_urls={
        "Bug Tracker": "https://github.com/ongchi/wagtail-showsimilar/issues",
    },
    install_requires=['wagtail>=2.3'],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Framework :: Django',
        'Framework :: Django :: 2.2',
        'Framework :: Django :: 3.0',
        'Framework :: Django :: 3.1',
        'Framework :: Wagtail',
        'Framework :: Wagtail :: 2',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.6",
)
